@@ -64,7 +64,7 @@ CamelType
 camel_exchange_journal_get_type (void)
 {
 	static CamelType type = 0;
-	
+
 	if (!type) {
 		type = camel_type_register (camel_offline_journal_get_type (),
 					    "CamelExchangeJournal",
@@ -75,7 +75,7 @@ camel_exchange_journal_get_type (void)
 					    (CamelObjectInitFunc) camel_exchange_journal_init,
 					    (CamelObjectFinalizeFunc) camel_exchange_journal_finalize);
 	}
-	
+
 	return type;
 }
 
@@ -83,9 +83,9 @@ static void
 camel_exchange_journal_class_init (CamelExchangeJournalClass *klass)
 {
 	CamelOfflineJournalClass *journal_class = (CamelOfflineJournalClass *) klass;
-	
+
 	parent_class = (CamelOfflineJournalClass *) camel_type_get_global_classfuncs (CAMEL_TYPE_OFFLINE_JOURNAL);
-	
+
 	journal_class->entry_free = exchange_entry_free;
 	journal_class->entry_load = exchange_entry_load;
 	journal_class->entry_write = exchange_entry_write;
@@ -95,20 +95,20 @@ camel_exchange_journal_class_init (CamelExchangeJournalClass *klass)
 static void
 camel_exchange_journal_init (CamelExchangeJournal *journal, CamelExchangeJournalClass *klass)
 {
-	
+
 }
 
 static void
 camel_exchange_journal_finalize (CamelObject *object)
 {
-	
+
 }
 
 static void
 exchange_entry_free (CamelOfflineJournal *journal, EDListNode *entry)
 {
 	CamelExchangeJournalEntry *exchange_entry = (CamelExchangeJournalEntry *) entry;
-	
+
 	g_free (exchange_entry->uid);
 	g_free (exchange_entry->original_uid);
 	g_free (exchange_entry->folder_name);
@@ -120,17 +120,17 @@ exchange_entry_load (CamelOfflineJournal *journal, FILE *in)
 {
 	CamelExchangeJournalEntry *entry;
 	char *tmp;
-	
+
 	entry = g_malloc0 (sizeof (CamelExchangeJournalEntry));
-	
+
 	if (camel_file_util_decode_uint32 (in, (guint32 *) &entry->type) == -1)
 		goto exception;
-	
+
 	switch (entry->type) {
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND:
 		if (camel_file_util_decode_string (in, &entry->uid) == -1)
 			goto exception;
-		
+
 		break;
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_TRANSFER:
 		if (camel_file_util_decode_string (in, &entry->uid) == -1)
@@ -162,16 +162,16 @@ exchange_entry_load (CamelOfflineJournal *journal, FILE *in)
 	default:
 		goto exception;
 	}
-	
+
 	return (EDListNode *) entry;
-	
+
  exception:
-	
+
 	g_free (entry->folder_name);
 	g_free (entry->original_uid);
 	g_free (entry->uid);
 	g_free (entry);
-	
+
 	return NULL;
 }
 
@@ -180,10 +180,10 @@ exchange_entry_write (CamelOfflineJournal *journal, EDListNode *entry, FILE *out
 {
 	CamelExchangeJournalEntry *exchange_entry = (CamelExchangeJournalEntry *) entry;
 	char *tmp;
-	
+
 	if (camel_file_util_encode_uint32 (out, exchange_entry->type) == -1)
 		return -1;
-	
+
 	switch (exchange_entry->type) {
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND:
 		if (camel_file_util_encode_string (out, exchange_entry->uid))
@@ -213,9 +213,10 @@ exchange_entry_write (CamelOfflineJournal *journal, EDListNode *entry, FILE *out
 		g_free (tmp);
 		break;
 	default:
-		g_assert_not_reached ();
+		g_critical ("%s: Uncaught case (%d)", G_STRLOC, exchange_entry->type);
+		return -1;
 	}
-	
+
 	return 0;
 }
 
@@ -249,7 +250,7 @@ exchange_entry_play_delete (CamelOfflineJournal *journal, CamelExchangeJournalEn
 
 	return 0;
 }
-				
+
 static int
 exchange_entry_play_append (CamelOfflineJournal *journal, CamelExchangeJournalEntry *entry, CamelException *ex)
 {
@@ -260,28 +261,28 @@ exchange_entry_play_append (CamelOfflineJournal *journal, CamelExchangeJournalEn
 	CamelStream *stream;
 	CamelException lex;
 	char *uid = NULL;
-	
+
 	/* if the message isn't in the cache, the user went behind our backs so "not our problem" */
 	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, ex)))
 		goto done;
-	
+
 	message = camel_mime_message_new ();
 	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream) == -1) {
 		camel_object_unref (message);
 		camel_object_unref (stream);
 		goto done;
 	}
-	
+
 	camel_object_unref (stream);
-	
+
 	if (!(info = camel_folder_summary_uid (folder->summary, entry->uid))) {
 		/* Should have never happened, but create a new info to avoid further crashes */
 		info = camel_message_info_new (NULL);
 	}
-	
+
 	camel_exception_init (&lex);
 	camel_folder_append_message (folder, message, info, &uid, &lex);
-	
+
 	if (camel_exception_is_set (&lex)) {
 		camel_exception_xfer (ex, &lex);
 		return -1;
@@ -298,15 +299,15 @@ exchange_entry_play_append (CamelOfflineJournal *journal, CamelExchangeJournalEn
 	}
 	camel_message_info_free (info);
 	g_free (uid);
-	
+
  done:
-	
+
 	camel_exchange_folder_remove_message (exchange_folder, entry->uid);
-	
+
 	return 0;
 }
 
-static int 
+static int
 exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournalEntry *entry, CamelException *ex)
 {
 	CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) journal->folder;
@@ -321,14 +322,14 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 
 	if (!exchange_folder->cache || !(stream = camel_data_cache_get (exchange_folder->cache, "cache", entry->uid, ex)))
 		goto done;
-	
+
 	message = camel_mime_message_new ();
 	if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream) == -1) {
 		camel_object_unref (message);
 		camel_object_unref (stream);
 		goto done;
 	}
-	
+
 	camel_object_unref (stream);
 
 	if (!(info = camel_folder_summary_uid (folder->summary, entry->uid))) {
@@ -340,12 +341,12 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("No folder name found\n"));
 		goto exception;
 	}
-	
+
 	store = (CamelExchangeStore *) folder->parent_store;
 	g_mutex_lock (store->folders_lock);
 	src = (CamelFolder *) g_hash_table_lookup (store->folders, entry->folder_name);
 	g_mutex_unlock (store->folders_lock);
-	
+
 	if (src) {
 		uids = g_ptr_array_sized_new (1);
 		g_ptr_array_add (uids, entry->original_uid);
@@ -367,8 +368,8 @@ exchange_entry_play_transfer (CamelOfflineJournal *journal, CamelExchangeJournal
 
 		g_ptr_array_free (xuids, TRUE);
 		g_ptr_array_free (uids, TRUE);
-		/* camel_object_unref (src); FIXME: should we? */ 
-	} 
+		/* camel_object_unref (src); FIXME: should we? */
+	}
 	else {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Folder doesn't exist"));
 		goto exception;
@@ -381,7 +382,7 @@ done:
 	return 0;
 
 exception:
-	
+
 	camel_message_info_free (info);
 
 	return -1;
@@ -391,7 +392,7 @@ static int
 exchange_entry_play (CamelOfflineJournal *journal, EDListNode *entry, CamelException *ex)
 {
 	CamelExchangeJournalEntry *exchange_entry = (CamelExchangeJournalEntry *) entry;
-	
+
 	switch (exchange_entry->type) {
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND:
 		return exchange_entry_play_append (journal, exchange_entry, ex);
@@ -400,7 +401,7 @@ exchange_entry_play (CamelOfflineJournal *journal, EDListNode *entry, CamelExcep
 	case CAMEL_EXCHANGE_JOURNAL_ENTRY_DELETE:
 		return exchange_entry_play_delete (journal, exchange_entry, ex);
 	default:
-		g_assert_not_reached ();
+		g_critical ("%s: Uncaught case (%d)", G_STRLOC, exchange_entry->type);
 		return -1;
 	}
 }
@@ -411,12 +412,12 @@ CamelOfflineJournal *
 camel_exchange_journal_new (CamelExchangeFolder *folder, const char *filename)
 {
 	CamelOfflineJournal *journal;
-	
+
 	g_return_val_if_fail (CAMEL_IS_EXCHANGE_FOLDER (folder), NULL);
-	
+
 	journal = (CamelOfflineJournal *) camel_object_new (camel_exchange_journal_get_type ());
 	camel_offline_journal_construct (journal, (CamelFolder *) folder, filename);
-	
+
 	return journal;
 }
 
@@ -437,16 +438,16 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 				     _("Cannot append message in offline mode: cache unavailable"));
 		return FALSE;
 	}
-	
+
 	nextuid = camel_folder_summary_next_uid (folder->summary);
 	uid = g_strdup_printf ("-%u", nextuid);
-	
+
 	if (!(cache = camel_data_cache_add (exchange_folder->cache, "cache", uid, ex))) {
 		folder->summary->nextuid--;
 		g_free (uid);
 		return FALSE;
 	}
-	
+
 	if (camel_data_wrapper_write_to_stream ((CamelDataWrapper *) message, cache) == -1
 	    || camel_stream_flush (cache) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
@@ -458,16 +459,16 @@ update_cache (CamelExchangeJournal *exchange_journal, CamelMimeMessage *message,
 		g_free (uid);
 		return FALSE;
 	}
-	
+
 	camel_object_unref (cache);
-	
+
 	info = camel_folder_summary_info_new_from_message (folder->summary, message);
 	info->uid = g_strdup (uid);
-	
+
 	exchange_message_info_dup_to ((CamelMessageInfoBase *) info, (CamelMessageInfoBase *) mi);
 
 	camel_folder_summary_add (folder->summary, info);
-	
+
 	if (updated_uid)
 		*updated_uid = g_strdup (uid);
 
@@ -483,16 +484,16 @@ camel_exchange_journal_append (CamelExchangeJournal *exchange_journal, CamelMime
 	CamelOfflineJournal *journal = (CamelOfflineJournal *) exchange_journal;
 	CamelExchangeJournalEntry *entry;
 	char *uid;
-	
+
 	if (!update_cache (exchange_journal, message, mi, &uid, ex))
 		return;
-	
+
 	entry = g_new (CamelExchangeJournalEntry, 1);
 	entry->type = CAMEL_EXCHANGE_JOURNAL_ENTRY_APPEND;
 	entry->uid = uid;
-	
+
 	e_dlist_addtail (&journal->queue, (EDListNode *) entry);
-	
+
 	if (appended_uid)
 		*appended_uid = g_strdup (uid);
 
@@ -509,7 +510,7 @@ find_real_source_for_message (CamelExchangeFolder *folder,
 	CamelExchangeJournalEntry *ex_entry;
 	const char *offline_uid = *uid;
 	int type = -1;
-	
+
 	if (*offline_uid != '-') {
 		return CAMEL_EXCHANGE_JOURNAL_ENTRY_TRANSFER;
 	}
@@ -517,7 +518,7 @@ find_real_source_for_message (CamelExchangeFolder *folder,
 	entry = journal->queue.head;
 	while (entry->next) {
 		next = entry->next;
-		
+
 		ex_entry = (CamelExchangeJournalEntry *) entry;
 		if (!g_ascii_strcasecmp (ex_entry->uid, offline_uid)) {
 			if (ex_entry->type == CAMEL_EXCHANGE_JOURNAL_ENTRY_TRANSFER) {
@@ -532,14 +533,14 @@ find_real_source_for_message (CamelExchangeFolder *folder,
 				e_dlist_remove (entry);
 			}
 		}
-		
+
 		entry = next;
 	}
 
 	return type;
 }
 
-void 
+void
 camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelExchangeFolder *source_folder,
 				CamelMimeMessage *message, const CamelMessageInfo *mi,
 				const char *original_uid, char **transferred_uid, gboolean delete_original,
@@ -550,16 +551,16 @@ camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelEx
 	char *uid;
 	const char *real_source_folder = NULL, *real_uid = NULL;
 	int type;
-	
+
 	if (!update_cache (exchange_journal, message, mi, &uid, ex))
 		return;
 
 	real_uid = original_uid;
 	real_source_folder = ((CamelFolder *)source_folder)->full_name;
-	
+
 	type = find_real_source_for_message (source_folder, &real_source_folder,
 					     &real_uid, delete_original);
-	
+
 	if(delete_original) {
 		camel_exchange_folder_remove_message (source_folder, original_uid);
 	}
@@ -575,7 +576,7 @@ camel_exchange_journal_transfer (CamelExchangeJournal *exchange_journal, CamelEx
 	}
 
 	e_dlist_addtail (&journal->queue, (EDListNode *) entry);
-	
+
 	if (transferred_uid)
 		*transferred_uid = g_strdup (uid);
 }
